<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>خطای عبارت</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>حالت ساده</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>حالت علمی</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>ماشین حساب دیپین</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>ماشین حساب دیپین یک ماشین حساب ساده و راحت، برای استفاده در میزکار است. این ماشین حساب، جمع، تفریق، ضرب و تقسیم را پشتیبانی می‌کند.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>خطای عبارت</translation>
    </message>
</context>
</TS>